Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
/var/devmt/py/dbilib_0.4.1/dbilib/__init__.py | (no class) | 1 | 0 | 0 | 100%
/var/devmt/py/dbilib_0.4.1/dbilib/_dbi_base.py | SecurityWarning | 0 | 0 | 0 | 100%
/var/devmt/py/dbilib_0.4.1/dbilib/_dbi_base.py | _DBIBase | 32 | 0 | 20 | 100%
/var/devmt/py/dbilib_0.4.1/dbilib/_dbi_base.py | (no class) | 22 | 0 | 1 | 100%
/var/devmt/py/dbilib_0.4.1/dbilib/_dbi_mysql.py | _DBIMySQL | 48 | 0 | 12 | 100%
/var/devmt/py/dbilib_0.4.1/dbilib/_dbi_mysql.py | (no class) | 13 | 0 | 0 | 100%
/var/devmt/py/dbilib_0.4.1/dbilib/_dbi_sqlite.py | _DBISQLite | 10 | 0 | 0 | 100%
/var/devmt/py/dbilib_0.4.1/dbilib/_dbi_sqlite.py | (no class) | 7 | 0 | 0 | 100%
/var/devmt/py/dbilib_0.4.1/dbilib/_version.py | (no class) | 1 | 0 | 0 | 100%
/var/devmt/py/dbilib_0.4.1/dbilib/database.py | DBInterface | 15 | 0 | 5 | 100%
/var/devmt/py/dbilib_0.4.1/dbilib/database.py | (no class) | 10 | 0 | 0 | 100%
Total |  | 159 | 0 | 38 | 100%

No items found using the specified filter.